@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -131,28 +131,28 @@ __PACKAGE__->method_documentation({
      'filter_columns' => {
      	datatype => 'ARRAY[FilterColumn]',
      	base_name => 'FilterColumns',
-     	description => '',
+     	description => 'Gets the collection of the filter columns.',
      	format => '',
      	read_only => '',
      		},
      'range' => {
      	datatype => 'string',
      	base_name => 'Range',
-     	description => '',
+     	description => 'Represents the range to which the specified AutoFilter applies.',
      	format => '',
      	read_only => '',
      		},
      'sorter' => {
      	datatype => 'DataSorter',
      	base_name => 'Sorter',
-     	description => '',
+     	description => 'Gets the data sorter.',
      	format => '',
      	read_only => '',
      		},
      'show_filter_button' => {
      	datatype => 'boolean',
      	base_name => 'ShowFilterButton',
-     	description => '',
+     	description => 'Indicates whether the AutoFilter button for this column is visible.',
      	format => '',
      	read_only => '',
      		},
