@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -129,98 +129,98 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'Name',
-     	description => '',
+     	description => 'Gets the name of the cell.',
      	format => '',
      	read_only => '',
      		},
      'row' => {
      	datatype => 'int',
      	base_name => 'Row',
-     	description => '',
+     	description => 'Gets row number (zero based) of the cell.',
      	format => '',
      	read_only => '',
      		},
      'column' => {
      	datatype => 'int',
      	base_name => 'Column',
-     	description => '',
+     	description => 'Gets column number (zero based) of the cell.',
      	format => '',
      	read_only => '',
      		},
      'value' => {
      	datatype => 'string',
      	base_name => 'Value',
-     	description => '',
+     	description => 'Gets the value contained in this cell.',
      	format => '',
      	read_only => '',
      		},
      'type' => {
      	datatype => 'string',
      	base_name => 'Type',
-     	description => '',
+     	description => 'Represents cell value type.',
      	format => '',
      	read_only => '',
      		},
      'formula' => {
      	datatype => 'string',
      	base_name => 'Formula',
-     	description => '',
+     	description => 'Gets or sets a formula of the .',
      	format => '',
      	read_only => '',
      		},
      'is_formula' => {
      	datatype => 'boolean',
      	base_name => 'IsFormula',
-     	description => '',
+     	description => 'Represents if the specified cell contains formula.',
      	format => '',
      	read_only => '',
      		},
      'is_merged' => {
      	datatype => 'boolean',
      	base_name => 'IsMerged',
-     	description => '',
+     	description => 'Checks if a cell is part of a merged range or not.',
      	format => '',
      	read_only => '',
      		},
      'is_array_header' => {
      	datatype => 'boolean',
      	base_name => 'IsArrayHeader',
-     	description => '',
+     	description => 'Indicates the cell`s formula is and array formula                         and it is the first cell of the array.',
      	format => '',
      	read_only => '',
      		},
      'is_in_array' => {
      	datatype => 'boolean',
      	base_name => 'IsInArray',
-     	description => '',
+     	description => 'Indicates whether the cell formula is an array formula.',
      	format => '',
      	read_only => '',
      		},
      'is_error_value' => {
      	datatype => 'boolean',
      	base_name => 'IsErrorValue',
-     	description => '',
+     	description => 'Checks if the value of this cell is an error.',
      	format => '',
      	read_only => '',
      		},
      'is_in_table' => {
      	datatype => 'boolean',
      	base_name => 'IsInTable',
-     	description => '',
+     	description => 'Indicates whether this cell is part of table formula.',
      	format => '',
      	read_only => '',
      		},
      'is_style_set' => {
      	datatype => 'boolean',
      	base_name => 'IsStyleSet',
-     	description => '',
+     	description => 'Indicates if the cell`s style is set. If return false, it means this cell has a default cell format.',
      	format => '',
      	read_only => '',
      		},
      'html_string' => {
      	datatype => 'string',
      	base_name => 'HtmlString',
-     	description => '',
+     	description => 'Gets and sets the html string which contains data and some formats in this cell.',
      	format => '',
      	read_only => '',
      		},
@@ -234,7 +234,7 @@ __PACKAGE__->method_documentation({
      'worksheet' => {
      	datatype => 'string',
      	base_name => 'Worksheet',
-     	description => '',
+     	description => 'Gets the parent worksheet.',
      	format => '',
      	read_only => '',
      		},
