@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -118,7 +118,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Cells Cloud File information description.',
                                   class => 'CellsCloudFileInfo',
                                   required => [], # TODO
 }                                 );
@@ -128,28 +128,28 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'Name',
-     	description => '',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
      'size' => {
      	datatype => 'int',
      	base_name => 'Size',
-     	description => '',
+     	description => 'The file size.',
      	format => '',
      	read_only => '',
      		},
      'folder' => {
      	datatype => 'string',
      	base_name => 'Folder',
-     	description => '',
+     	description => 'The file position.',
      	format => '',
      	read_only => '',
      		},
      'storage' => {
      	datatype => 'string',
      	base_name => 'Storage',
-     	description => '',
+     	description => 'The storage name.',
      	format => '',
      	read_only => '',
      		},    
