@@ -35,7 +35,6 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
-use AsposeCellsCloud::Object::DataSource;
 use AsposeCellsCloud::Object::FileSource;
 use AsposeCellsCloud::Object::OperateObject;
 use AsposeCellsCloud::Object::OperateParameter;
@@ -122,7 +121,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => 'Represents cells object operate task parameter.',
+__PACKAGE__->class_documentation({description => '',
                                   class => 'CellsObjectOperateTaskParameter',
                                   required => [], # TODO
 }                                 );
@@ -132,28 +131,21 @@ __PACKAGE__->method_documentation({
      'operate_object' => {
      	datatype => 'OperateObject',
      	base_name => 'OperateObject',
-     	description => 'Represents object operate.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'operate_parameter' => {
      	datatype => 'OperateParameter',
      	base_name => 'OperateParameter',
-     	description => 'Represents operate parameter.',
-     	format => '',
-     	read_only => '',
-     		},
-     'destination_data_source' => {
-     	datatype => 'DataSource',
-     	base_name => 'DestinationDataSource',
-     	description => 'Represents destination data source.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'destination_workbook' => {
      	datatype => 'FileSource',
      	base_name => 'DestinationWorkbook',
-     	description => 'Represents destination data source.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},    
@@ -162,14 +154,12 @@ __PACKAGE__->method_documentation({
 __PACKAGE__->swagger_types( {
     'operate_object' => 'OperateObject',
     'operate_parameter' => 'OperateParameter',
-    'destination_data_source' => 'DataSource',
     'destination_workbook' => 'FileSource' 
 } );
 
 __PACKAGE__->attribute_map( {
     'operate_object' => 'OperateObject',
     'operate_parameter' => 'OperateParameter',
-    'destination_data_source' => 'DestinationDataSource',
     'destination_workbook' => 'DestinationWorkbook' 
 } );
 
