@@ -119,7 +119,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => 'Represents the ChartArea Response.',
+__PACKAGE__->class_documentation({description => '',
                                   class => 'ChartAreaResponse',
                                   required => [], # TODO
 }                                 );
