@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -133,56 +133,56 @@ __PACKAGE__->method_documentation({
      'area' => {
      	datatype => 'Area',
      	base_name => 'Area',
-     	description => '',
+     	description => 'Gets the area.',
      	format => '',
      	read_only => '',
      		},
      'border' => {
      	datatype => 'Line',
      	base_name => 'Border',
-     	description => '',
+     	description => 'Gets the border.',
      	format => '',
      	read_only => '',
      		},
      'data_labels' => {
      	datatype => 'DataLabels',
      	base_name => 'DataLabels',
-     	description => '',
+     	description => 'Returns a DataLabels object that represents the data label associated with the point.',
      	format => '',
      	read_only => '',
      		},
      'explosion' => {
      	datatype => 'int',
      	base_name => 'Explosion',
-     	description => '',
+     	description => 'The distance of an open pie slice from the center of the pie chart is expressed as a percentage of the pie diameter.',
      	format => '',
      	read_only => '',
      		},
      'marker' => {
      	datatype => 'Marker',
      	base_name => 'Marker',
-     	description => '',
+     	description => 'Gets the marker.',
      	format => '',
      	read_only => '',
      		},
      'shadow' => {
      	datatype => 'boolean',
      	base_name => 'Shadow',
-     	description => '',
+     	description => 'True if the chartpoint has a shadow.',
      	format => '',
      	read_only => '',
      		},
      'x_value' => {
      	datatype => 'string',
      	base_name => 'XValue',
-     	description => '',
+     	description => 'Gets or sets the X value of the chart point.',
      	format => '',
      	read_only => '',
      		},
      'y_value' => {
      	datatype => 'string',
      	base_name => 'YValue',
-     	description => '',
+     	description => 'Gets or sets the Y value of the chart point.',
      	format => '',
      	read_only => '',
      		},
