@@ -35,7 +35,6 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
-use AsposeCellsCloud::Object::ChartPoint;
 use AsposeCellsCloud::Object::Link;
 use AsposeCellsCloud::Object::LinkElement; 
 
@@ -120,7 +119,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => 'Represents a collection that contains all the points in one series.',
+__PACKAGE__->class_documentation({description => '',
                                   class => 'ChartPoints',
                                   required => [], # TODO
 }                                 );
@@ -128,7 +127,7 @@ __PACKAGE__->class_documentation({description => 'Represents a collection that c
 
 __PACKAGE__->method_documentation({
      'chart_point_list' => {
-     	datatype => 'ARRAY[ChartPoint]',
+     	datatype => 'ARRAY[LinkElement]',
      	base_name => 'ChartPointList',
      	description => '',
      	format => '',
@@ -144,7 +143,7 @@ __PACKAGE__->method_documentation({
 });
 
 __PACKAGE__->swagger_types( {
-    'chart_point_list' => 'ARRAY[ChartPoint]',
+    'chart_point_list' => 'ARRAY[LinkElement]',
     'link' => 'Link' 
 } );
 
