@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -130,21 +130,21 @@ __PACKAGE__->method_documentation({
      'checked_value' => {
      	datatype => 'string',
      	base_name => 'CheckedValue',
-     	description => '',
+     	description => 'Gets or set checkbox` value.',
      	format => '',
      	read_only => '',
      		},
      'shadow' => {
      	datatype => 'boolean',
      	base_name => 'Shadow',
-     	description => '',
+     	description => 'Indicates whether the combobox has 3-D shading.',
      	format => '',
      	read_only => '',
      		},
      'value' => {
      	datatype => 'boolean',
      	base_name => 'Value',
-     	description => '',
+     	description => 'Indicates if the checkbox is checked or not.',
      	format => '',
      	read_only => '',
      		},
