@@ -119,7 +119,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => 'Represents a single column in a worksheet.',
+__PACKAGE__->class_documentation({description => '',
                                   class => 'Column',
                                   required => [], # TODO
 }                                 );
