@@ -118,7 +118,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '           Describes the values of the interpolation points in a gradient scale, dataBar or iconSet.           ',
+__PACKAGE__->class_documentation({description => '',
                                   class => 'ConditionalFormattingValue',
                                   required => [], # TODO
 }                                 );
