@@ -35,7 +35,6 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
-use AsposeCellsCloud::Object::DataSource;
 use AsposeCellsCloud::Object::FileSource;
 use AsposeCellsCloud::Object::SaveOptions;
 use AsposeCellsCloud::Object::TaskParameter; 
@@ -121,52 +120,44 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => 'Represents convert task parameter.',
+__PACKAGE__->class_documentation({description => '',
                                   class => 'ConvertTaskParameter',
                                   required => [], # TODO
 }                                 );
 
 
 __PACKAGE__->method_documentation({
-     'data_source' => {
-     	datatype => 'DataSource',
-     	base_name => 'DataSource',
-     	description => 'Represents data source of task object.',
-     	format => '',
-     	read_only => '',
-     		},
      'workbook' => {
      	datatype => 'FileSource',
      	base_name => 'Workbook',
-     	description => 'Represents data source of task object.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'destination_file' => {
      	datatype => 'string',
      	base_name => 'DestinationFile',
-     	description => 'Represents destination file.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'region' => {
      	datatype => 'string',
      	base_name => 'Region',
-     	description => 'Represents Excel data region.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'save_options' => {
      	datatype => 'SaveOptions',
      	base_name => 'SaveOptions',
-     	description => 'Represents save options.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},    
 });
 
 __PACKAGE__->swagger_types( {
-    'data_source' => 'DataSource',
     'workbook' => 'FileSource',
     'destination_file' => 'string',
     'region' => 'string',
@@ -174,7 +165,6 @@ __PACKAGE__->swagger_types( {
 } );
 
 __PACKAGE__->attribute_map( {
-    'data_source' => 'DataSource',
     'workbook' => 'Workbook',
     'destination_file' => 'DestinationFile',
     'region' => 'Region',
