@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -128,14 +128,14 @@ __PACKAGE__->method_documentation({
      'column_index' => {
      	datatype => 'int',
      	base_name => 'ColumnIndex',
-     	description => '',
+     	description => 'Point Column',
      	format => '',
      	read_only => '',
      		},
      'parse_method' => {
      	datatype => 'string',
      	base_name => 'ParseMethod',
-     	description => '',
+     	description => 'data parser method.             ToDateTime            ToString',
      	format => '',
      	read_only => '',
      		},
