@@ -119,7 +119,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => 'Represents the DataLabels Response.',
+__PACKAGE__->class_documentation({description => '',
                                   class => 'DataLabelsResponse',
                                   required => [], # TODO
 }                                 );
