@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -128,49 +128,49 @@ __PACKAGE__->method_documentation({
      'date_time_grouping_type' => {
      	datatype => 'string',
      	base_name => 'DateTimeGroupingType',
-     	description => '',
+     	description => 'Gets and sets the group type.',
      	format => '',
      	read_only => '',
      		},
      'day' => {
      	datatype => 'int',
      	base_name => 'Day',
-     	description => '',
+     	description => 'Gets and sets the day of the grouped date time.',
      	format => '',
      	read_only => '',
      		},
      'hour' => {
      	datatype => 'int',
      	base_name => 'Hour',
-     	description => '',
+     	description => 'Gets and sets the hour of the grouped date time.',
      	format => '',
      	read_only => '',
      		},
      'minute' => {
      	datatype => 'int',
      	base_name => 'Minute',
-     	description => '',
+     	description => 'Gets and sets the minute of the grouped date time.',
      	format => '',
      	read_only => '',
      		},
      'month' => {
      	datatype => 'int',
      	base_name => 'Month',
-     	description => '',
+     	description => 'Gets and sets the month of the grouped date time.',
      	format => '',
      	read_only => '',
      		},
      'second' => {
      	datatype => 'int',
      	base_name => 'Second',
-     	description => '',
+     	description => 'Gets and sets the second of the grouped date time.',
      	format => '',
      	read_only => '',
      		},
      'year' => {
      	datatype => 'int',
      	base_name => 'Year',
-     	description => '',
+     	description => 'Gets and sets the year of the grouped date time.',
      	format => '',
      	read_only => '',
      		},    
