@@ -38,7 +38,8 @@ use DateTime;
 use AsposeCellsCloud::Object::Area;
 use AsposeCellsCloud::Object::ChartFrame;
 use AsposeCellsCloud::Object::Font;
-use AsposeCellsCloud::Object::Line; 
+use AsposeCellsCloud::Object::Line;
+use AsposeCellsCloud::Object::LinkElement; 
 
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
@@ -121,7 +122,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => 'Represents the display unit label.',
+__PACKAGE__->class_documentation({description => '',
                                   class => 'DisplayUnitLabel',
                                   required => [], # TODO
 }                                 );
@@ -149,6 +150,13 @@ __PACKAGE__->method_documentation({
      	format => '',
      	read_only => '',
      		},
+     'text_direction' => {
+     	datatype => 'string',
+     	base_name => 'TextDirection',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},
      'text_horizontal_alignment' => {
      	datatype => 'string',
      	base_name => 'TextHorizontalAlignment',
@@ -219,6 +227,13 @@ __PACKAGE__->method_documentation({
      	format => '',
      	read_only => '',
      		},
+     'shape_properties' => {
+     	datatype => 'ARRAY[LinkElement]',
+     	base_name => 'ShapeProperties',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},
      'width' => {
      	datatype => 'int',
      	base_name => 'Width',
@@ -253,6 +268,7 @@ __PACKAGE__->swagger_types( {
     'linked_source' => 'string',
     'rotation_angle' => 'int',
     'text' => 'string',
+    'text_direction' => 'string',
     'text_horizontal_alignment' => 'string',
     'text_vertical_alignment' => 'string',
     'area' => 'Area',
@@ -263,6 +279,7 @@ __PACKAGE__->swagger_types( {
     'is_automatic_size' => 'boolean',
     'is_inner_mode' => 'boolean',
     'shadow' => 'boolean',
+    'shape_properties' => 'ARRAY[LinkElement]',
     'width' => 'int',
     'height' => 'int',
     'x' => 'int',
@@ -273,6 +290,7 @@ __PACKAGE__->attribute_map( {
     'linked_source' => 'LinkedSource',
     'rotation_angle' => 'RotationAngle',
     'text' => 'Text',
+    'text_direction' => 'TextDirection',
     'text_horizontal_alignment' => 'TextHorizontalAlignment',
     'text_vertical_alignment' => 'TextVerticalAlignment',
     'area' => 'Area',
@@ -283,6 +301,7 @@ __PACKAGE__->attribute_map( {
     'is_automatic_size' => 'IsAutomaticSize',
     'is_inner_mode' => 'IsInnerMode',
     'shadow' => 'Shadow',
+    'shape_properties' => 'ShapeProperties',
     'width' => 'Width',
     'height' => 'Height',
     'x' => 'X',
