@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -131,14 +131,14 @@ __PACKAGE__->method_documentation({
      'area' => {
      	datatype => 'Area',
      	base_name => 'Area',
-     	description => '',
+     	description => 'Gets the .',
      	format => '',
      	read_only => '',
      		},
      'border' => {
      	datatype => 'Line',
      	base_name => 'Border',
-     	description => '',
+     	description => 'Gets the border .',
      	format => '',
      	read_only => '',
      		},
