@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -131,42 +131,42 @@ __PACKAGE__->method_documentation({
      'type' => {
      	datatype => 'string',
      	base_name => 'Type',
-     	description => '',
+     	description => 'Gets and sets the fill type. ',
      	format => '',
      	read_only => '',
      		},
      'solid_fill' => {
      	datatype => 'SolidFill',
      	base_name => 'SolidFill',
-     	description => '',
+     	description => 'Gets  object. ',
      	format => '',
      	read_only => '',
      		},
      'pattern_fill' => {
      	datatype => 'PatternFill',
      	base_name => 'PatternFill',
-     	description => '',
+     	description => 'Gets  object. ',
      	format => '',
      	read_only => '',
      		},
      'texture_fill' => {
      	datatype => 'TextureFill',
      	base_name => 'TextureFill',
-     	description => '',
+     	description => 'Gets  object. ',
      	format => '',
      	read_only => '',
      		},
      'gradient_fill' => {
      	datatype => 'GradientFill',
      	base_name => 'GradientFill',
-     	description => '',
+     	description => 'Gets  object. ',
      	format => '',
      	read_only => '',
      		},
      'image_data' => {
      	datatype => 'string',
      	base_name => 'ImageData',
-     	description => '',
+     	description => 'Gets and sets the picture image data. ',
      	format => '',
      	read_only => '',
      		},    
