@@ -118,7 +118,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '           Represents the gradient fill.           ',
+__PACKAGE__->class_documentation({description => '',
                                   class => 'GradientFill',
                                   required => [], # TODO
 }                                 );
