@@ -120,7 +120,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => 'Represents the group shape which contains the individual shapes.',
+__PACKAGE__->class_documentation({description => '',
                                   class => 'GroupShape',
                                   required => [], # TODO
 }                                 );
