@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -130,35 +130,35 @@ __PACKAGE__->method_documentation({
      'address' => {
      	datatype => 'string',
      	base_name => 'Address',
-     	description => '',
+     	description => 'Represents the address of a hyperlink.',
      	format => '',
      	read_only => '',
      		},
      'area' => {
      	datatype => 'CellArea',
      	base_name => 'Area',
-     	description => '',
+     	description => 'Gets the range of hyperlink.',
      	format => '',
      	read_only => '',
      		},
      'screen_tip' => {
      	datatype => 'string',
      	base_name => 'ScreenTip',
-     	description => '',
+     	description => 'Returns or sets the ScreenTip text for the specified hyperlink.',
      	format => '',
      	read_only => '',
      		},
      'text_to_display' => {
      	datatype => 'string',
      	base_name => 'TextToDisplay',
-     	description => '',
+     	description => 'Represents the text to be displayed for the specified hyperlink. The default value is the address of the hyperlink.',
      	format => '',
      	read_only => '',
      		},
      'link_type' => {
      	datatype => 'string',
      	base_name => 'LinkType',
-     	description => '',
+     	description => 'Gets the link type.',
      	format => '',
      	read_only => '',
      		},
