@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -119,7 +119,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Indicates import xml data request',
                                   class => 'ImportXMLRequest',
                                   required => [], # TODO
 }                                 );
@@ -138,18 +138,27 @@ __PACKAGE__->method_documentation({
      	base_name => 'ImportPosition',
      	description => 'Import position description.',
      	format => '',
+     	read_only => '',
+     		},
+     'xml_content' => {
+     	datatype => 'string',
+     	base_name => 'XMLContent',
+     	description => 'Base64String default is null',
+     	format => '',
      	read_only => '',
      		},    
 });
 
 __PACKAGE__->swagger_types( {
     'xml_file_source' => 'FileSource',
-    'import_position' => 'ImportPosition' 
+    'import_position' => 'ImportPosition',
+    'xml_content' => 'string' 
 } );
 
 __PACKAGE__->attribute_map( {
     'xml_file_source' => 'XMLFileSource',
-    'import_position' => 'ImportPosition' 
+    'import_position' => 'ImportPosition',
+    'xml_content' => 'XMLContent' 
 } );
 
 __PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});
