@@ -122,7 +122,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => 'Encapsulates the object that represents the chart legend.',
+__PACKAGE__->class_documentation({description => '',
                                   class => 'Legend',
                                   required => [], # TODO
 }                                 );
@@ -199,6 +199,13 @@ __PACKAGE__->method_documentation({
      	format => '',
      	read_only => '',
      		},
+     'shape_properties' => {
+     	datatype => 'ARRAY[LinkElement]',
+     	base_name => 'ShapeProperties',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},
      'width' => {
      	datatype => 'int',
      	base_name => 'Width',
@@ -240,6 +247,7 @@ __PACKAGE__->swagger_types( {
     'is_automatic_size' => 'boolean',
     'is_inner_mode' => 'boolean',
     'shadow' => 'boolean',
+    'shape_properties' => 'ARRAY[LinkElement]',
     'width' => 'int',
     'height' => 'int',
     'x' => 'int',
@@ -257,6 +265,7 @@ __PACKAGE__->attribute_map( {
     'is_automatic_size' => 'IsAutomaticSize',
     'is_inner_mode' => 'IsInnerMode',
     'shadow' => 'Shadow',
+    'shape_properties' => 'ShapeProperties',
     'width' => 'Width',
     'height' => 'Height',
     'x' => 'X',
