@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -130,28 +130,28 @@ __PACKAGE__->method_documentation({
      'auto_scale_font' => {
      	datatype => 'string',
      	base_name => 'AutoScaleFont',
-     	description => '',
+     	description => 'True if the text in the object changes font size when the object size changes.                         The default value is True.',
      	format => '',
      	read_only => '',
      		},
      'background_mode' => {
      	datatype => 'string',
      	base_name => 'BackgroundMode',
-     	description => '',
+     	description => 'Gets and sets the display mode of the background',
      	format => '',
      	read_only => '',
      		},
      'font' => {
      	datatype => 'Font',
      	base_name => 'Font',
-     	description => '',
+     	description => 'Gets a  object of the specified ChartFrame object.',
      	format => '',
      	read_only => '',
      		},
      'is_deleted' => {
      	datatype => 'string',
      	base_name => 'IsDeleted',
-     	description => '',
+     	description => 'Gets and sets whether the legend entry is deleted.',
      	format => '',
      	read_only => '',
      		},
