@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -135,14 +135,14 @@ __PACKAGE__->method_documentation({
      'interrupt_monitor' => {
      	datatype => 'string',
      	base_name => 'InterruptMonitor',
-     	description => '',
+     	description => 'Gets and sets the interrupt monitor.',
      	format => '',
      	read_only => '',
      		},
      'language_code' => {
      	datatype => 'string',
      	base_name => 'LanguageCode',
-     	description => '',
+     	description => 'Gets or sets the user interface language of the Workbook version based on CountryCode that has saved the file.',
      	format => '',
      	read_only => '',
      		},
@@ -156,7 +156,7 @@ __PACKAGE__->method_documentation({
      'load_format' => {
      	datatype => 'string',
      	base_name => 'LoadFormat',
-     	description => '',
+     	description => 'Gets the load format.',
      	format => '',
      	read_only => '',
      		},
@@ -170,35 +170,35 @@ __PACKAGE__->method_documentation({
      'parsing_formula_on_open' => {
      	datatype => 'string',
      	base_name => 'ParsingFormulaOnOpen',
-     	description => '',
+     	description => 'Indicates whether parsing the formula when reading the file.',
      	format => '',
      	read_only => '',
      		},
      'password' => {
      	datatype => 'string',
      	base_name => 'Password',
-     	description => '',
+     	description => 'Gets and set the password of the workbook.',
      	format => '',
      	read_only => '',
      		},
      'region' => {
      	datatype => 'string',
      	base_name => 'Region',
-     	description => '',
+     	description => 'Gets or sets the system regional settings based on CountryCode at the time the file was loaded.',
      	format => '',
      	read_only => '',
      		},
      'standard_font' => {
      	datatype => 'string',
      	base_name => 'StandardFont',
-     	description => '',
+     	description => 'Sets the default standard font name',
      	format => '',
      	read_only => '',
      		},
      'standard_font_size' => {
      	datatype => 'double',
      	base_name => 'StandardFontSize',
-     	description => '',
+     	description => 'Sets the default standard font size.',
      	format => '',
      	read_only => '',
      		},    
