@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -129,7 +129,7 @@ __PACKAGE__->method_documentation({
      'comment' => {
      	datatype => 'string',
      	base_name => 'Comment',
-     	description => '',
+     	description => 'Gets and sets the comment of the name.                        Only applies for Excel 2007.',
      	format => '',
      	read_only => '',
      		},
@@ -143,35 +143,35 @@ __PACKAGE__->method_documentation({
      'is_referred' => {
      	datatype => 'boolean',
      	base_name => 'IsReferred',
-     	description => '',
+     	description => 'Indicates whether this name is referred by other formulas.',
      	format => '',
      	read_only => '',
      		},
      'is_visible' => {
      	datatype => 'boolean',
      	base_name => 'IsVisible',
-     	description => '',
+     	description => 'Indicates whether the name is visible.',
      	format => '',
      	read_only => '',
      		},
      'r1_c1_refers_to' => {
      	datatype => 'string',
      	base_name => 'R1C1RefersTo',
-     	description => '',
+     	description => 'Gets or sets a R1C1 reference of the .',
      	format => '',
      	read_only => '',
      		},
      'refers_to' => {
      	datatype => 'string',
      	base_name => 'RefersTo',
-     	description => '',
+     	description => 'Returns or sets the formula that the name is defined to refer to, beginning with an equal sign.',
      	format => '',
      	read_only => '',
      		},
      'text' => {
      	datatype => 'string',
      	base_name => 'Text',
-     	description => '',
+     	description => 'Gets the name text of the object.',
      	format => '',
      	read_only => '',
      		},
