@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -128,42 +128,42 @@ __PACKAGE__->method_documentation({
      'type' => {
      	datatype => 'string',
      	base_name => 'Type',
-     	description => '',
+     	description => 'Gets or sets the picture fill type. ',
      	format => '',
      	read_only => '',
      		},
      'scale' => {
      	datatype => 'double',
      	base_name => 'Scale',
-     	description => '',
+     	description => 'Gets or sets how many the picture stack and scale with. ',
      	format => '',
      	read_only => '',
      		},
      'left' => {
      	datatype => 'double',
      	base_name => 'Left',
-     	description => '',
+     	description => 'Gets or sets the left offset for stretching picture. ',
      	format => '',
      	read_only => '',
      		},
      'right' => {
      	datatype => 'double',
      	base_name => 'Right',
-     	description => '',
+     	description => 'Gets or sets the right offset for stretching picture. ',
      	format => '',
      	read_only => '',
      		},
      'top' => {
      	datatype => 'double',
      	base_name => 'Top',
-     	description => '',
+     	description => 'Gets or sets the top offset for stretching picture. ',
      	format => '',
      	read_only => '',
      		},
      'bottom' => {
      	datatype => 'double',
      	base_name => 'Bottom',
-     	description => '',
+     	description => 'Gets or sets the bottom offset for stretching picture. ',
      	format => '',
      	read_only => '',
      		},    
