@@ -118,7 +118,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '           Represents a item in a PivotField report.           ',
+__PACKAGE__->class_documentation({description => '',
                                   class => 'PivotItem',
                                   required => [], # TODO
 }                                 );
