@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -118,7 +118,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Represents the various types of protection options available for a worksheet.            ',
                                   class => 'Protection',
                                   required => [], # TODO
 }                                 );
@@ -128,119 +128,119 @@ __PACKAGE__->method_documentation({
      'allow_deleting_column' => {
      	datatype => 'boolean',
      	base_name => 'AllowDeletingColumn',
-     	description => '',
+     	description => 'Represents if the deletion of columns is allowed on a protected worksheet. ',
      	format => '',
      	read_only => '',
      		},
      'allow_deleting_row' => {
      	datatype => 'boolean',
      	base_name => 'AllowDeletingRow',
-     	description => '',
+     	description => 'Represents if the deletion of rows is allowed on a protected worksheet. ',
      	format => '',
      	read_only => '',
      		},
      'allow_filtering' => {
      	datatype => 'boolean',
      	base_name => 'AllowFiltering',
-     	description => '',
+     	description => 'Represents if the user is allowed to make use of an AutoFilter that was created before the sheet was protected. ',
      	format => '',
      	read_only => '',
      		},
      'allow_formatting_cell' => {
      	datatype => 'boolean',
      	base_name => 'AllowFormattingCell',
-     	description => '',
+     	description => 'Represents if the formatting of cells is allowed on a protected worksheet. ',
      	format => '',
      	read_only => '',
      		},
      'allow_formatting_column' => {
      	datatype => 'boolean',
      	base_name => 'AllowFormattingColumn',
-     	description => '',
+     	description => 'Represents if the formatting of columns is allowed on a protected worksheet ',
      	format => '',
      	read_only => '',
      		},
      'allow_formatting_row' => {
      	datatype => 'boolean',
      	base_name => 'AllowFormattingRow',
-     	description => '',
+     	description => 'Represents if the formatting of rows is allowed on a protected worksheet ',
      	format => '',
      	read_only => '',
      		},
      'allow_inserting_column' => {
      	datatype => 'boolean',
      	base_name => 'AllowInsertingColumn',
-     	description => '',
+     	description => 'Represents if the insertion of columns is allowed on a protected worksheet ',
      	format => '',
      	read_only => '',
      		},
      'allow_inserting_hyperlink' => {
      	datatype => 'boolean',
      	base_name => 'AllowInsertingHyperlink',
-     	description => '',
+     	description => 'Represents if the insertion of hyperlinks is allowed on a protected worksheet ',
      	format => '',
      	read_only => '',
      		},
      'allow_inserting_row' => {
      	datatype => 'boolean',
      	base_name => 'AllowInsertingRow',
-     	description => '',
+     	description => 'Represents if the insertion of rows is allowed on a protected worksheet ',
      	format => '',
      	read_only => '',
      		},
      'allow_sorting' => {
      	datatype => 'boolean',
      	base_name => 'AllowSorting',
-     	description => '',
+     	description => 'Represents if the sorting option is allowed on a protected worksheet. ',
      	format => '',
      	read_only => '',
      		},
      'allow_using_pivot_table' => {
      	datatype => 'boolean',
      	base_name => 'AllowUsingPivotTable',
-     	description => '',
+     	description => 'Represents if the user is allowed to manipulate pivot tables on a protected worksheet. ',
      	format => '',
      	read_only => '',
      		},
      'allow_editing_content' => {
      	datatype => 'boolean',
      	base_name => 'AllowEditingContent',
-     	description => '',
+     	description => 'Represents if the user is allowed to edit contents of locked cells on a protected worksheet. ',
      	format => '',
      	read_only => '',
      		},
      'allow_editing_object' => {
      	datatype => 'boolean',
      	base_name => 'AllowEditingObject',
-     	description => '',
+     	description => 'Represents if the user is allowed to manipulate drawing objects on a protected worksheet. ',
      	format => '',
      	read_only => '',
      		},
      'allow_editing_scenario' => {
      	datatype => 'boolean',
      	base_name => 'AllowEditingScenario',
-     	description => '',
+     	description => 'Represents if the user is allowed to edit scenarios on a protected worksheet. ',
      	format => '',
      	read_only => '',
      		},
      'password' => {
      	datatype => 'string',
      	base_name => 'Password',
-     	description => '',
+     	description => 'Represents the password to protect the worksheet. ',
      	format => '',
      	read_only => '',
      		},
      'allow_selecting_locked_cell' => {
      	datatype => 'boolean',
      	base_name => 'AllowSelectingLockedCell',
-     	description => '',
+     	description => 'Represents if the user is allowed to select locked cells on a protected worksheet. ',
      	format => '',
      	read_only => '',
      		},
      'allow_selecting_unlocked_cell' => {
      	datatype => 'boolean',
      	base_name => 'AllowSelectingUnlockedCell',
-     	description => '',
+     	description => 'Represents if the user is allowed to select unlocked cells on a protected worksheet. ',
      	format => '',
      	read_only => '',
      		},    
