@@ -118,7 +118,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => 'Font for rendering.',
+__PACKAGE__->class_documentation({description => '',
                                   class => 'RenderingFont',
                                   required => [], # TODO
 }                                 );
