@@ -118,7 +118,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => 'Represents sort key.',
+__PACKAGE__->class_documentation({description => '',
                                   class => 'SortKey',
                                   required => [], # TODO
 }                                 );
@@ -128,14 +128,14 @@ __PACKAGE__->method_documentation({
      'key' => {
      	datatype => 'int',
      	base_name => 'Key',
-     	description => 'Represents the key of sorting.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'sort_order' => {
      	datatype => 'string',
      	base_name => 'SortOrder',
-     	description => 'Represents the order of sorting.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
