@@ -35,7 +35,6 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
-use AsposeCellsCloud::Object::DataSource;
 use AsposeCellsCloud::Object::FileSource;
 use AsposeCellsCloud::Object::TaskParameter; 
 
@@ -120,7 +119,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => 'Represents split workbook task parameter.',
+__PACKAGE__->class_documentation({description => '',
                                   class => 'SplitWorkbookTaskParameter',
                                   required => [], # TODO
 }                                 );
@@ -130,35 +129,21 @@ __PACKAGE__->method_documentation({
      'workbook' => {
      	datatype => 'FileSource',
      	base_name => 'Workbook',
-     	description => 'Represents data source of task object.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'destination_file_position' => {
      	datatype => 'FileSource',
      	base_name => 'DestinationFilePosition',
-     	description => 'Represents data source of task object.',
-     	format => '',
-     	read_only => '',
-     		},
-     'data_source' => {
-     	datatype => 'DataSource',
-     	base_name => 'DataSource',
-     	description => 'Represents destination data source.',
-     	format => '',
-     	read_only => '',
-     		},
-     'target_data_source' => {
-     	datatype => 'DataSource',
-     	base_name => 'TargetDataSource',
-     	description => 'Represents destination data source.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'destination_file_format' => {
      	datatype => 'string',
      	base_name => 'DestinationFileFormat',
-     	description => 'Represents destination data file format.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
@@ -188,8 +173,6 @@ __PACKAGE__->method_documentation({
 __PACKAGE__->swagger_types( {
     'workbook' => 'FileSource',
     'destination_file_position' => 'FileSource',
-    'data_source' => 'DataSource',
-    'target_data_source' => 'DataSource',
     'destination_file_format' => 'string',
     'split_name_rule' => 'string',
     'vertical_resolution' => 'int',
@@ -199,8 +182,6 @@ __PACKAGE__->swagger_types( {
 __PACKAGE__->attribute_map( {
     'workbook' => 'Workbook',
     'destination_file_position' => 'DestinationFilePosition',
-    'data_source' => 'DataSource',
-    'target_data_source' => 'TargetDataSource',
     'destination_file_format' => 'DestinationFileFormat',
     'split_name_rule' => 'SplitNameRule',
     'vertical_resolution' => 'VerticalResolution',
