@@ -121,7 +121,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '           Represents display style of excel document,such as font,color,alignment,border,etc.            The Style object contains all style attributes (font, number format, alignment, and so on) as properties.           ',
+__PACKAGE__->class_documentation({description => '',
                                   class => 'Style',
                                   required => [], # TODO
 }                                 );
