@@ -118,7 +118,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => 'Represents task result parameter.',
+__PACKAGE__->class_documentation({description => '',
                                   class => 'TaskResultParameter',
                                   required => [], # TODO
 }                                 );
