@@ -158,13 +158,6 @@ __PACKAGE__->method_documentation({
      	base_name => 'Width',
      	description => 'Indicates image width.',
      	format => '',
-     	read_only => '',
-     		},
-     'image_adapt_option' => {
-     	datatype => 'string',
-     	base_name => 'ImageAdaptOption',
-     	description => '',
-     	format => '',
      	read_only => '',
      		},    
 });
@@ -174,8 +167,7 @@ __PACKAGE__->swagger_types( {
     'font_name' => 'string',
     'font_size' => 'int',
     'height' => 'int',
-    'width' => 'int',
-    'image_adapt_option' => 'string' 
+    'width' => 'int' 
 } );
 
 __PACKAGE__->attribute_map( {
@@ -183,8 +175,7 @@ __PACKAGE__->attribute_map( {
     'font_name' => 'FontName',
     'font_size' => 'FontSize',
     'height' => 'Height',
-    'width' => 'Width',
-    'image_adapt_option' => 'ImageAdaptOption' 
+    'width' => 'Width' 
 } );
 
 __PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});
