@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -137,161 +137,161 @@ __PACKAGE__->method_documentation({
      'display_right_to_left' => {
      	datatype => 'boolean',
      	base_name => 'DisplayRightToLeft',
-     	description => 'Indicates if the specified worksheet is displayed from right to left instead   of from left to right.  Default is false.            ',
+     	description => 'Indicates if the specified worksheet is displayed from right to left instead of from left to right.            Default is false. ',
      	format => '',
      	read_only => '',
      		},
      'display_zeros' => {
      	datatype => 'boolean',
      	base_name => 'DisplayZeros',
-     	description => 'True if zero values are displayed.',
+     	description => 'True if zero values are displayed. ',
      	format => '',
      	read_only => '',
      		},
      'first_visible_column' => {
      	datatype => 'int',
      	base_name => 'FirstVisibleColumn',
-     	description => 'Represents first visible column index.',
+     	description => 'Represents first visible column index. ',
      	format => '',
      	read_only => '',
      		},
      'first_visible_row' => {
      	datatype => 'int',
      	base_name => 'FirstVisibleRow',
-     	description => 'Represents first visible row index.            ',
+     	description => 'Represents first visible row index. ',
      	format => '',
      	read_only => '',
      		},
      'name' => {
      	datatype => 'string',
      	base_name => 'Name',
-     	description => 'Gets or sets the name of the worksheet.            ',
+     	description => 'Gets or sets the name of the worksheet. ',
      	format => '',
      	read_only => '',
      		},
      'index' => {
      	datatype => 'int',
      	base_name => 'Index',
-     	description => 'Gets the index of sheet in the worksheets collection.            ',
+     	description => 'Gets the index of sheet in the worksheet collection. ',
      	format => '',
      	read_only => '',
      		},
      'is_gridlines_visible' => {
      	datatype => 'boolean',
      	base_name => 'IsGridlinesVisible',
-     	description => 'Gets or sets a value indicating whether the gridelines are visible.Default    is true.',
+     	description => 'Gets or sets a value indicating whether the gridlines are visible.Default is true. ',
      	format => '',
      	read_only => '',
      		},
      'is_outline_shown' => {
      	datatype => 'boolean',
      	base_name => 'IsOutlineShown',
-     	description => 'Indicates whether show outline.            ',
+     	description => 'Indicates whether to show outline. ',
      	format => '',
      	read_only => '',
      		},
      'is_page_break_preview' => {
      	datatype => 'boolean',
      	base_name => 'IsPageBreakPreview',
-     	description => 'Indications the specified worksheet is shown in normal view or page break preview.',
+     	description => 'Indicates whether the specified worksheet is shown in normal view or page break preview. ',
      	format => '',
      	read_only => '',
      		},
      'is_visible' => {
      	datatype => 'boolean',
      	base_name => 'IsVisible',
-     	description => 'Represents if the worksheet is visible.            ',
+     	description => 'Represents if the worksheet is visible. ',
      	format => '',
      	read_only => '',
      		},
      'is_protected' => {
      	datatype => 'boolean',
      	base_name => 'IsProtected',
-     	description => 'Indicates if the worksheet is protected.',
+     	description => 'Indicates if the worksheet is protected. ',
      	format => '',
      	read_only => '',
      		},
      'is_row_column_headers_visible' => {
      	datatype => 'boolean',
      	base_name => 'IsRowColumnHeadersVisible',
-     	description => 'Gets or sets a value indicating whether the worksheet will display row and column headers.Default is true.            ',
+     	description => 'Gets or sets a value indicating whether the worksheet will display row and column headers.            Default is true. ',
      	format => '',
      	read_only => '',
      		},
      'is_ruler_visible' => {
      	datatype => 'boolean',
      	base_name => 'IsRulerVisible',
-     	description => 'Indicates whether the ruler is visible. Only apply for page break preview.',
+     	description => 'Indicates whether the ruler is visible. This property is only applied for page break preview. ',
      	format => '',
      	read_only => '',
      		},
      'is_selected' => {
      	datatype => 'boolean',
      	base_name => 'IsSelected',
-     	description => 'Indicates whether this worksheet is selected when the workbook is opened.',
+     	description => 'Indicates whether this worksheet is selected when the workbook is opened. ',
      	format => '',
      	read_only => '',
      		},
      'tab_color' => {
      	datatype => 'Color',
      	base_name => 'TabColor',
-     	description => 'Represents worksheet tab color.',
+     	description => 'Represents worksheet tab color. ',
      	format => '',
      	read_only => '',
      		},
      'transition_entry' => {
      	datatype => 'boolean',
      	base_name => 'TransitionEntry',
-     	description => 'Flag indicating whether the Transition Formula Entry (Lotus compatibility) option is enabled.',
+     	description => 'Indicates whether the Transition Formula Entry (Lotus compatibility) option is enabled. ',
      	format => '',
      	read_only => '',
      		},
      'transition_evaluation' => {
      	datatype => 'boolean',
      	base_name => 'TransitionEvaluation',
-     	description => 'Flag indicating whether the Transition Formula Evaluation (Lotus compatibility) option is enabled.            ',
+     	description => 'Indicates whether the Transition Formula Evaluation (Lotus compatibility) option is enabled. ',
      	format => '',
      	read_only => '',
      		},
      'type' => {
      	datatype => 'string',
      	base_name => 'Type',
-     	description => 'Represents worksheet type',
+     	description => 'Represents worksheet type. ',
      	format => '',
      	read_only => '',
      		},
      'view_type' => {
      	datatype => 'string',
      	base_name => 'ViewType',
-     	description => 'Gets and sets the view type.',
+     	description => 'Gets and sets the view type. ',
      	format => '',
      	read_only => '',
      		},
      'visibility_type' => {
      	datatype => 'string',
      	base_name => 'VisibilityType',
-     	description => 'Indicates the state for this sheet visibility            ',
+     	description => 'Indicates the visible state for this sheet. ',
      	format => '',
      	read_only => '',
      		},
      'zoom' => {
      	datatype => 'int',
      	base_name => 'Zoom',
-     	description => 'Represents the scaling factor in percent. It should be btween 10 and 400.            ',
+     	description => 'Represents the scaling factor in percentage. It should be between 10 and 400. ',
      	format => '',
      	read_only => '',
      		},
      'cells' => {
      	datatype => 'LinkElement',
      	base_name => 'Cells',
-     	description => '',
+     	description => 'Gets the  collection. ',
      	format => '',
      	read_only => '',
      		},
      'charts' => {
      	datatype => 'LinkElement',
      	base_name => 'Charts',
-     	description => '',
+     	description => 'Gets a  collection ',
      	format => '',
      	read_only => '',
      		},
@@ -305,21 +305,21 @@ __PACKAGE__->method_documentation({
      'ole_objects' => {
      	datatype => 'LinkElement',
      	base_name => 'OleObjects',
-     	description => '',
+     	description => 'Represents a collection of  in a worksheet. ',
      	format => '',
      	read_only => '',
      		},
      'comments' => {
      	datatype => 'LinkElement',
      	base_name => 'Comments',
-     	description => '',
+     	description => 'Gets the  collection. ',
      	format => '',
      	read_only => '',
      		},
      'pictures' => {
      	datatype => 'LinkElement',
      	base_name => 'Pictures',
-     	description => '',
+     	description => 'Gets a  collection. ',
      	format => '',
      	read_only => '',
      		},
@@ -333,21 +333,21 @@ __PACKAGE__->method_documentation({
      'validations' => {
      	datatype => 'LinkElement',
      	base_name => 'Validations',
-     	description => '',
+     	description => 'Gets the data validation setting collection in the worksheet. ',
      	format => '',
      	read_only => '',
      		},
      'conditional_formattings' => {
      	datatype => 'LinkElement',
      	base_name => 'ConditionalFormattings',
-     	description => '',
+     	description => 'Gets the ConditionalFormattings in the worksheet. ',
      	format => '',
      	read_only => '',
      		},
      'hyperlinks' => {
      	datatype => 'LinkElement',
      	base_name => 'Hyperlinks',
-     	description => '',
+     	description => 'Gets the  collection. ',
      	format => '',
      	read_only => '',
      		},    
