@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,9 +59,9 @@ sub new {
 
 
 # Run Operation Request
-# DeleteWorkbookNamesRequest.name :   ,
-# DeleteWorkbookNamesRequest.folder :   ,
-# DeleteWorkbookNamesRequest.storageName :    
+# DeleteWorkbookNamesRequest.name : The file name.  ,
+# DeleteWorkbookNamesRequest.folder : The folder where the file is situated.  ,
+# DeleteWorkbookNamesRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -72,7 +72,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'delete_workbook_names' } = { 
-    	summary => '',
+    	summary => 'Delete all named ranges in the workbook.',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -123,21 +123,21 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => '',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => '',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => '',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
