@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,12 +59,12 @@ sub new {
 
 
 # Run Operation Request
-# DeleteWorksheetPivotTableFiltersRequest.name :   ,
-# DeleteWorksheetPivotTableFiltersRequest.sheetName :   ,
-# DeleteWorksheetPivotTableFiltersRequest.pivotTableIndex :   ,
-# DeleteWorksheetPivotTableFiltersRequest.needReCalculate :   ,
-# DeleteWorksheetPivotTableFiltersRequest.folder :   ,
-# DeleteWorksheetPivotTableFiltersRequest.storageName :    
+# DeleteWorksheetPivotTableFiltersRequest.name : The file name.  ,
+# DeleteWorksheetPivotTableFiltersRequest.sheetName : The worksheet name.  ,
+# DeleteWorksheetPivotTableFiltersRequest.pivotTableIndex : The PivotTable index.  ,
+# DeleteWorksheetPivotTableFiltersRequest.needReCalculate : Whether the specific PivotTable calculate(true/false).  ,
+# DeleteWorksheetPivotTableFiltersRequest.folder : The folder where the file is situated.  ,
+# DeleteWorksheetPivotTableFiltersRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -75,7 +75,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'delete_worksheet_pivot_table_filters' } = { 
-    	summary => '',
+    	summary => 'Delete all pivot filters in the PivotTable.',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -142,42 +142,42 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => '',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
      'sheet_name' => {
      	datatype => 'string',
      	base_name => 'sheetName',
-     	description => '',
+     	description => 'The worksheet name.',
      	format => '',
      	read_only => '',
      		},
      'pivot_table_index' => {
      	datatype => 'int',
      	base_name => 'pivotTableIndex',
-     	description => '',
+     	description => 'The PivotTable index.',
      	format => '',
      	read_only => '',
      		},
      'need_re_calculate' => {
      	datatype => 'string',
      	base_name => 'needReCalculate',
-     	description => '',
+     	description => 'Whether the specific PivotTable calculate(true/false).',
      	format => '',
      	read_only => '',
      		},
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => '',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => '',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
