@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,10 +59,10 @@ sub new {
 
 
 # Run Operation Request
-# DeleteWorksheetPivotTablesRequest.name : The workbook name.  ,
+# DeleteWorksheetPivotTablesRequest.name : The file name.  ,
 # DeleteWorksheetPivotTablesRequest.sheetName : The worksheet name.  ,
-# DeleteWorksheetPivotTablesRequest.folder : Original workbook folder.  ,
-# DeleteWorksheetPivotTablesRequest.storageName : Storage name.   
+# DeleteWorksheetPivotTablesRequest.folder : The folder where the file is situated.  ,
+# DeleteWorksheetPivotTablesRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -73,7 +73,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'delete_worksheet_pivot_tables' } = { 
-    	summary => 'Delete pivot tables in worksheet.',
+    	summary => 'Delete PivotTables in the worksheet.',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -130,7 +130,7 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => 'The workbook name.',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
@@ -144,14 +144,14 @@ __PACKAGE__->method_documentation({
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => 'Original workbook folder.',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => 'Storage name.',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
