@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,15 +59,15 @@ sub new {
 
 
 # Run Operation Request
-# GetWorksheetWithFormatRequest.name : The workbook name.  ,
+# GetWorksheetWithFormatRequest.name : The file name.  ,
 # GetWorksheetWithFormatRequest.sheetName : The worksheet name.  ,
 # GetWorksheetWithFormatRequest.format : Export format(CSV/XLS/HTML/MHTML/ODS/PDF/XML/TXT/TIFF/XLSB/XLSM/XLSX/XLTM/XLTX/XPS/PNG/JPG/JPEG/GIF/EMF/BMP/MD[Markdown]/Numbers).  ,
 # GetWorksheetWithFormatRequest.verticalResolution : Image vertical resolution.  ,
 # GetWorksheetWithFormatRequest.horizontalResolution : Image horizontal resolution.  ,
 # GetWorksheetWithFormatRequest.area : Represents the range to be printed.  ,
 # GetWorksheetWithFormatRequest.pageIndex : Represents the page to be printed  ,
-# GetWorksheetWithFormatRequest.folder : Original workbook folder.  ,
-# GetWorksheetWithFormatRequest.storageName : Storage name.   
+# GetWorksheetWithFormatRequest.folder : The folder where the file is situated.  ,
+# GetWorksheetWithFormatRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -78,7 +78,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'get_worksheet_with_format' } = { 
-    	summary => 'Gets worksheet in some format.',
+    	summary => 'Retrieve the worksheet in a specified format from the workbook.',
         params => $params,
         returns => 'string',
     };
@@ -155,7 +155,7 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => 'The workbook name.',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
@@ -204,14 +204,14 @@ __PACKAGE__->method_documentation({
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => 'Original workbook folder.',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => 'Storage name.',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
