@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,12 +59,12 @@ sub new {
 
 
 # Run Operation Request
-# PostUpdateWorksheetOleObjectRequest.name : The workbook name.  ,
+# PostUpdateWorksheetOleObjectRequest.name : The file name.  ,
 # PostUpdateWorksheetOleObjectRequest.sheetName : The worsheet name.  ,
 # PostUpdateWorksheetOleObjectRequest.oleObjectIndex : Ole object index.  ,
 # PostUpdateWorksheetOleObjectRequest.ole : Ole Object description.  ,
-# PostUpdateWorksheetOleObjectRequest.folder : Original workbook folder.  ,
-# PostUpdateWorksheetOleObjectRequest.storageName : Storage name.   
+# PostUpdateWorksheetOleObjectRequest.folder : The folder where the file is situated.  ,
+# PostUpdateWorksheetOleObjectRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -144,7 +144,7 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => 'The workbook name.',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
@@ -172,14 +172,14 @@ __PACKAGE__->method_documentation({
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => 'Original workbook folder.',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => 'Storage name.',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
