@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,9 +59,9 @@ sub new {
 
 
 # Run Operation Request
-# PostWorksheetCellsRangeSortRequest.name : The workbook name.  ,
+# PostWorksheetCellsRangeSortRequest.name : The file name.  ,
 # PostWorksheetCellsRangeSortRequest.sheetName : The worksheet name.  ,
-# PostWorksheetCellsRangeSortRequest.rangeOperate : Range Set OutlineBorder Request   ,
+# PostWorksheetCellsRangeSortRequest.rangeSortRequest : RangeSortRequest Range Sort Request   ,
 # PostWorksheetCellsRangeSortRequest.folder : Original workbook folder.  ,
 # PostWorksheetCellsRangeSortRequest.storageName : Storage name.   
 
@@ -74,7 +74,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'post_worksheet_cells_range_sort' } = { 
-    	summary => 'Sets outline border around a range of cells.',
+    	summary => 'Perform data sorting around a range of cells.',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -120,9 +120,9 @@ sub run_http_request {
     my $_body_data;
 
     # body params
-    if (defined $self->range_operate) {
-        #$_body_data = $self->range_operate;
-         $_body_data = JSON->new->convert_blessed->encode( $self->range_operate);
+    if (defined $self->range_sort_request) {
+        #$_body_data = $self->range_sort_request;
+         $_body_data = JSON->new->convert_blessed->encode( $self->range_sort_request);
     }
     # authentication setting, if any
     my $auth_settings = [qw()];
@@ -137,7 +137,7 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => 'The workbook name.',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
@@ -148,10 +148,10 @@ __PACKAGE__->method_documentation({
      	format => '',
      	read_only => '',
      		},
-     'range_operate' => {
+     'range_sort_request' => {
      	datatype => 'RangeSortRequest',
-     	base_name => 'rangeOperate',
-     	description => 'Range Set OutlineBorder Request ',
+     	base_name => 'rangeSortRequest',
+     	description => 'RangeSortRequest Range Sort Request ',
      	format => '',
      	read_only => '',
      		},
@@ -175,7 +175,7 @@ __PACKAGE__->method_documentation({
 __PACKAGE__->attribute_map( {
     'name' => 'name',
     'sheet_name' => 'sheetName',
-    'range_operate' => 'rangeOperate',
+    'range_sort_request' => 'rangeSortRequest',
     'folder' => 'folder',
     'storage_name' => 'storageName' 
 } );
