@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,11 +59,11 @@ sub new {
 
 
 # Run Operation Request
-# PutInsertWorksheetRowRequest.name : The workbook name.  ,
+# PutInsertWorksheetRowRequest.name : The file name.  ,
 # PutInsertWorksheetRowRequest.sheetName : The worksheet name.  ,
 # PutInsertWorksheetRowRequest.rowIndex : The new row index.  ,
-# PutInsertWorksheetRowRequest.folder : Original workbook folder.  ,
-# PutInsertWorksheetRowRequest.storageName : Storage name.   
+# PutInsertWorksheetRowRequest.folder : The folder where the file is situated.  ,
+# PutInsertWorksheetRowRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -74,7 +74,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'put_insert_worksheet_row' } = { 
-    	summary => 'Inserts new row in worksheet.',
+    	summary => 'Insert a new row in the worksheet.',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -137,7 +137,7 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => 'The workbook name.',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
@@ -158,14 +158,14 @@ __PACKAGE__->method_documentation({
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => 'Original workbook folder.',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => 'Storage name.',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
