@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,7 +59,7 @@ sub new {
 
 
 # Run Operation Request
-# PutWorksheetAddPictureRequest.name : The workbook name.  ,
+# PutWorksheetAddPictureRequest.name : The file name.  ,
 # PutWorksheetAddPictureRequest.sheetName : The worsheet name.  ,
 # PutWorksheetAddPictureRequest.picture : Pictute object  ,
 # PutWorksheetAddPictureRequest.upperLeftRow : The image upper left row.  ,
@@ -67,8 +67,8 @@ sub new {
 # PutWorksheetAddPictureRequest.lowerRightRow : The image low right row.  ,
 # PutWorksheetAddPictureRequest.lowerRightColumn : The image low right column.  ,
 # PutWorksheetAddPictureRequest.picturePath : The picture path, if not provided the picture data is inspected in the request body.  ,
-# PutWorksheetAddPictureRequest.folder : Original workbook folder.  ,
-# PutWorksheetAddPictureRequest.storageName : Storage name.   
+# PutWorksheetAddPictureRequest.folder : The folder where the file is situated.  ,
+# PutWorksheetAddPictureRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -79,7 +79,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'put_worksheet_add_picture' } = { 
-    	summary => 'Adds a new picture in worksheet.',
+    	summary => 'Add a new picture in the worksheet.',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -162,7 +162,7 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => 'The workbook name.',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
@@ -218,14 +218,14 @@ __PACKAGE__->method_documentation({
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => 'Original workbook folder.',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => 'Storage name.',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
