@@ -61,8 +61,8 @@ has version_info => ( is => 'ro',
                       isa => 'HashRef',
                       default => sub { {
                           app_name => 'Aspose.Cells Cloud SDK APIs.',
-                          app_version => '24.12',
-                          generator_class => 'io.swagger.codegen.languages.PerlClientCodeGen',
+                          app_version => '24.3',
+                          generator_class => 'io.swagger.codegen.languages.PerlClientCodegen',
                       } },
                       documentation => 'Information about the application version and the codegen codebase version'
                       );
@@ -119,16 +119,16 @@ sub _build_af {
 
 AsposeCellsCloud::Role - a Moose role for the Aspose.Cells Cloud SDK APIs.
 
-=head2 Aspose.Cells Cloud SDK APIs. version: 24.12
+=head2 Aspose.Cells Cloud SDK APIs. version: 24.3
 
 =head1 VERSION
 
-Automatically generated by the Perl Swagger CodeGen project:
+Automatically generated by the Perl Swagger Codegen project:
 
 =over 4
-=item Build package: io.swagger.codegen.languages.PerlClientCodeGen
+=item Build package: io.swagger.codegen.languages.PerlClientCodegen
 
-=item CodeGen version:
+=item Codegen version:
 
 =back
 
@@ -139,7 +139,7 @@ AsposeCellsCloud::ApiFactory for non-Moosey usage.
 
 =head1 SYNOPSIS
 
-The Perl Swagger CodeGen project builds a library of Perl modules to interact with
+The Perl Swagger Codegen project builds a library of Perl modules to interact with
 a web service defined by a OpenAPI Specification. See below for how to build the
 library.
 
